@@ -1,4 +1,4 @@
-# Copyright 2014 - 2018 Avram Lubkin, All Rights Reserved
+# Copyright 2014 - 2025 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -13,7 +13,7 @@ from pluginlib import Parent, abstractmethod
 
 
 @Parent('parser', 'testdata')
-class Parser(object):
+class Parser:
     """Parser parent class"""
 
     @abstractmethod
@@ -22,7 +22,7 @@ class Parser(object):
 
 
 @Parent('engine', 'testdata')
-class Engine(object):
+class Engine:
     """Engine parent class"""
 
     @abstractmethod
@@ -31,5 +31,5 @@ class Engine(object):
 
 
 @Parent('hook', 'testdata')
-class Hook(object):
+class Hook:
     """Hook parent class"""
